export default {
  data: function data() {
    return {
      style: null
    };
  },

  watch: {
    type: function type() {
      this.applyType();
    },

    '$vuetify.theme': {
      deep: true,
      handler: function handler() {
        this.applyType();
      }
    }
  },

  mounted: function mounted() {
    this.genStyle();
    this.genThemeClasses();
    this.applyType();
  },


  methods: {
    applyType: function applyType() {
      this.genThemeClasses();
      this.$vuetify.theme.type = this.type;
    },
    genThemeClasses: function genThemeClasses() {
      this.updateTheme(this.genTheme());
    },
    genTheme: function genTheme() {
      return this.genColors(this.$vuetify.theme);
    },
    genColors: function genColors(theme) {
      var _this = this;

      return Object.keys(theme).map(function (key) {
        var value = theme[key];

        return _this.genBackgroundColor(key, value) + _this.genTextColor(key, value);
      }).join('');
    },
    genBackgroundColor: function genBackgroundColor(key, value) {
      return '.' + key + '{background-color:' + value + ' !important;border-color:' + value + ' !important;}';
    },
    genTextColor: function genTextColor(key, value) {
      return '.' + key + '--text{color:' + value + ' !important;}';
    },
    genStyle: function genStyle() {
      var style = document.createElement('style');
      style.type = 'text/css';
      document.head.appendChild(style);
      this.style = style;
    },
    updateTheme: function updateTheme(classes) {
      this.style.innerHTML = classes;
    }
  }
};